pyxcp.master package
====================

Submodules
----------

pyxcp.master.base module
------------------------

.. automodule:: pyxcp.master.base
    :members:
    :undoc-members:
    :show-inheritance:

pyxcp.master.pre35 module
-------------------------

.. automodule:: pyxcp.master.pre35
    :members:
    :undoc-members:
    :show-inheritance:

pyxcp.master.py35 module
------------------------

.. automodule:: pyxcp.master.py35
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyxcp.master
    :members:
    :undoc-members:
    :show-inheritance:
